/**********************************************************************************************
					INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
              DIRECCIN GENERAL PARA LA INTEGRACIN Y ANLISIS DE LA INFORMACIN
***********************************************************************************************

NOMBRE DEL PROGRAMA: RE02c_PEM2015.SAS
-----------------------------------------------------------------------------------------------

DESCRIPCIN DEL PROGRAMA:
Sintaxis utilizada para generar los valores de las tablas finales y graficos del indicador RE02c.
"Salario relativo por hora de los trabajadores segn nivel de escolaridad",
indicador del Panorama Educativo de Mxico 2015.
-----------------------------------------------------------------------------------------------

NOMBRE Y DESCRIPCIN DE ARCHIVOS DE ENTRADA:  
1.	Encuesta Nacional de Ocupacin y Empleo, Segundo trimestre de 2015. Inegi (2015) (Base de datos).
	SDEMT215  Datos del cuestionario sociodemogrfico bsico.
	COE1T215 y COE2T215 Datos del cuestionario de ocupacin y empleo bsico.
				Tipo: Encuesta 
				Unidad: Entidades federativas 
				Diseo muestral: Estratos
-----------------------------------------------------------------------------------------------

NOMBRE Y DESCRIPCIN DE ARCHIVOS DE SALIDA: 
En la carpeta "Sal_hor_rel" se generan siete archivos en formato Excel con los salarios promedios por hora, 
estos permiten generar las tablas del indicador al dividir el salario de poblacin con cierto nivel de escolaridad 
entre el salario de quienes tienen el nivel educativo de referencia, 
cada archivo corresponde a un grupo de edad.
SHR15c15_19.xls   (grupo de 15 a 19 aos)
SHR15c15_29.xls   (grupo de 15 a 29 aos)
SHR15c20_24.xls   (grupo de 20 a 24 aos)
SHR15c25_29.xls   (grupo de 25 a 29 aos)
SHR15c25_44.xls   (grupo de 25 a 44 aos)
SHR15c25_64.xls   (grupo de 25 a 64 aos)
SHR15c45_64.xls   (grupo de 45 a 64 aos)


Adicional, en la carpeta "May_10_sal_min" se generan siete archivos (uno por cada grupo de edad) con el promedio 
salarial de quienes perciben ms de 10 salarios mnimos mensuales.

Finalmente, en la carpeta work de SAS se generan las tablas con las pruebas de significancia estadstica por grupo de edad, 
por ejemplo, para el grupo de 15 a 29 aos, las tablas son:
Tabla_15_29_final          Pruebas de significancia de los salarios relativos por nivel de escolaridad y entidad federativa 
Tabla_15_29_final_sexo     Pruebas de significancia de los salarios relativos por nivel de escolaridad y sexo
Tabla_15_29_final_locur    Pruebas de significancia de los salarios relativos por nivel de escolaridad y tamao de localidad
Tloc2_15_29_final          Pruebas de significancia de los salarios relativos por nivel de escolaridad, entre tamaos de localidad 
Tosexo2_15_29_final        Pruebas de significancia de los salarios relativos por nivel de escolaridad, entre sexos
-----------------------------------------------------------------------------------------------

INSTRUCCIONES:
1. Cre tres carpetas, una que contenga las bases de la ENOE, segundo trimestre de 2015 en formato SAS, en este caso "ENOE_2015_T2\SAS",
   otra donde se guardaran los archivos de salarios mayores a 10SM (May_10_sal_min) y otra para los salarios relativos (Sal_hor_rel).
2. Modifique las lneas de comando "%let" de acuerdo con las rutas actualizadas.
3. Ejecute el programa.


*********************************************************************************************
ELABORADO POR: 
Guadalupe Torres Godinez      Fecha: 2011/24/04
MODIFICADO POR: 
Rodrigo Jimnez Uribe         Fecha: 2013/24/05
Jos Alberto Muos Hernndez  Fecha: 2014/21/05
Ral Guadalupe Antonio        Fecha: 2015/12/28
	Adscripcin: Direccin de Indicadores Educativos. Subdireccin de de Integracin de Informacin Social y Econmica. 
                              LTIMA MODIFICACIN: 2016/03/03
***********************************************************************************************/

/* Esta primer macro genera la base de trabajo, la variable escolaridad y las variables sexo,
   poblacin ocupada, posicin en el trabajo, horas trabajadas mensuales y mbito rural o urbano */

%let path=D:\rguadalupe\Documents\Ral\PEM\2015\Bases\Insumo\ENOE_2015_T2\SAS; /*Directorio bases ENOE*/
%let s10=D:\rguadalupe\Documents\Ral\PEM\2015\Programas\RE02c\Re02c_PEM2015_Rev\May_10_sal_min; /*Directorio guardar archivos promedio salarial de quienes perciben ms de 10 salarios mnimos mensuales*/
%let shr=D:\rguadalupe\Documents\Ral\PEM\2015\Programas\RE02c\Re02c_PEM2015_Rev\Sal_hor_rel; /*Directorio guardar archivos Salarios promedio por hora*/


%MACRO create(o=, b=, j=, c=, d=, e=, f=);
OPTIONS OPTIONS DATE LINESIZE=90 REPLACE PAGESIZE=80;
LIBNAME C "&path";
RUN;

/*  Secuencia de pegado de bases: */
DATA SDEMT2&b;  /*SDEMT*/
SET &o..SDEMT2&b;
	a=cd_a; x=ent; y=con; z=v_sel; e=n_hog; v=h_mud; g=n_ren;
	key=cat(a, x, y, z, e, v, g); 
RUN;

DATA COE1T2&b;  /* COE1T */
SET &o..COE1T2&b;
	a=cd_a; x=ent; y=con; z=v_sel; e=n_hog; v=h_mud; g=n_ren;
	key=cat(a, x, y, z, e, v, g);  /* key para COE1 */
RUN;

DATA COE2T2&b; /* COE2T */ 
SET &o..COE2T2&b;
	a=cd_a; x=ent; y=con; z=v_sel; e=n_hog; v=h_mud; g=n_ren;
	key=cat(a, x, y, z, e, v, g);  /* key para COE2 */
RUN;

/* Ordena base por key */
PROC SORT DATA=SDEMT2&b;                       	
	BY key;                       				
RUN;                       						
PROC SORT DATA=COE1T2&b;                       	
	BY key;                       				
RUN;                       						
PROC SORT DATA=COE2T2&b;                       	
	BY key;                       				
RUN;
	
/* Union de bases */
DATA ENOE2&b;
MERGE SDEMT2&b (IN=i) COE1T2&b COE2T2&b;      
BY key;
IF i;
RUN;

/* Variables Sexo, edad, estado, pob ocupada (po) */
DATA ENOE2&b.a;
SET ENOE2&b;
edad=eda+0;
sexo=sex+0;
estado=ent+0;
IF r_def='00' and c_res in ('1','3');
 
/*Poblacin ocupada - po=1 */
po=0;
if clase2=1 then po=1; 	

/* Posicin en el trabajo: pos */
p3h_n=p3h+0;
p3d_n=p3d+0;
p3g1_1n=p3g1_1+0;
 IF p3h_n in (2,3) THEN pos=0;							  /* subordinado no remunerado */
 IF po=1 AND p3h_n=1 THEN pos=1;						  /* subordinado remunerado */
 IF p3d_n=1 AND p3g1_1n=1 THEN pos=2;					  /* empleador */
 IF p3d_n in (2,9) OR (p3d_n=1 and p3g1_1n=.) THEN pos=3; /* cuentapropia */
 IF po=1 AND p3h_n=9 THEN pos=9;						  /* no especificado */

 /* Poblacin con contratacin estable (base, planta o indefinido) */
poce=0;
&j.n=&j+0;	 /*(cuestionario_2005_ampliado=p3K1 y 2011_bsico=p3j1 */
IF po=1 AND &j.n=2 THEN poce=1; 

/* Tamao de localidad */
t_locn=t_loc+0;
IF t_locn in (1,2) THEN locur=1;							  *Urbana;
IF t_locn=3        THEN locur=2;							  *Semiurbana;
IF t_locn=4        THEN locur=3;							  *Rural;


/* Idenficacin para eliminar entrevistas	incompletas de la base de datos SDEM */ 
if r_def ^='15';

niv=cs_p13_1+0;
gdo=cs_p13_2+0; *Aos aprobados;
ant=cs_p15+0;	*1=prim. 2=sec. 3=ms, 9=no esp.;
egreso=cs_p16+0;


/* ESCOLARIDAD ACORDE CON EL CINE2011 (OCDE) */

esc=.;

/* Educacin bsica. CINE 2011, NIVEL 0: Educacin de Primera infancia y poblacin sin instruccin */
							*[Sin instruccin y con preescolar];
IF niv in (0,1) THEN esc=0;
						   *[Prim. incompleta y gdos no espec.];
IF niv=2 & gdo in(1:5,9) THEN esc=0;

/* CINE 2011, NIVEL 1: Educacin Primaria */
IF niv=2 & gdo=6 THEN esc=0;          		  *[Prim. completa];
IF niv=3 & gdo in (1,2,9)THEN esc=0;*[Sec. inc,y gdo. no espec];
					   *[Normal con primaria sin egreso y n.e.];  
IF niv=5 & ant=1 & gdo in (1:9) & egreso in (2,9)	THEN esc=0; 
			   *[Carrera tcnica con primaria sin egreso y n.e]; 
IF niv=6 & ant=1 & gdo in (1:9) & egreso in (2,9)	THEN esc=0;

/* CINE 2011, NIVEL 2: Educacin Secundaria Baja */
							 			       *[Sec. completa];
IF niv=3 & gdo=3 						 			THEN esc=1;
						   *[Bach. incompleto y gdo. no espec.];
IF niv=4 & gdo in (1,2,9) 				 			THEN esc=1;
					 *[Carrera tcnica con primaria con egreso];
IF niv=6 & ant=1 & gdo in (1:9) & egreso=1 			THEN esc=1;
					  *[Normal con secundaria sin egreso y n.e];
IF niv=5 & ant=2 & gdo in (1:9) & egreso in (2,9)	THEN esc=1;
			*[Carrera tcnica con secundaria sin egreso y n.e.];
IF niv=6 & ant=2 & gdo in (1:9) & egreso in (2,9)	THEN esc=1;

/* Educacin media superior */
/* CINE 2011, NIVEL 3: Educacin Secundaria Alta */
											  *[Bach. completo];
IF niv=4 & gdo=3		     						THEN esc=2;
								*[Normal con primaria y egreso];
IF niv=5 & ant=1 & gdo in (1:9) & egreso=1 			THEN esc=2;
							  *[Normal con secundaria y egreso];
IF niv=5 & ant=2 & gdo in (1:9) & egreso=1 			THEN esc=2;
					 *[Carrera tcnica con secundaria y egreso];
IF niv=6 & ant=2 & gdo in (1:9) & egreso=1 			THEN esc=2;
				  *[Normal con bachillerato, sin egreso y n.e.];
IF niv=5 & ant=3 & gdo in (1:9) & egreso in (2,9)	THEN esc=2;
		 *[Carrera tcnica con bachillerato, sin egreso y n.e.];
IF niv=6 & ant=3 & gdo in (1:9) & egreso in (2,9)	THEN esc=2;
						    *[Lic. incompleta y gdo. no espec.];
IF niv=7 & gdo in (1:3,9) 		     	 			THEN esc=2;

/* Educacin superior */
/* CINE 2011, NIVEL 5: Educacin Terciaria de ciclo corto */
				 *[Carrera tc/comer. con bach., gdos: 3 o ms];
IF niv=6 & ant=3 & gdo in (1:9) & egreso=1			THEN esc=3;
/* CINE 2011, NIVEL 6: EDUCACIN Terciaria profesional */
									   *[Licenciatura completa];
IF niv=7 & gdo in (4:8) 			     			THEN esc=3;
							  *[Normal con bach., gdos:4 o ms];
IF niv=5 & ant=3 & gdo in (1:9) & egreso=1	     	THEN esc=3;
										 *[Maestra incompleta];
IF niv=8 & gdo in (1,9) 			     			THEN esc=3;
/*CINE2011, NIVEL 7:Niv maestra,especializacin o equivalente*/
										   *[Maestra completa];
IF niv=8 & gdo in (2:8) 			     			THEN esc=3;
							 *[Doctorado completo o incompleto];
IF niv=9 & gdo in (1:2,9)				 			THEN esc=3;
/* CINE 2011, NIVEL 8: Nivel de dcotorado o equivalente */
							 *[Doctorado completo o incompleto];
IF niv=9 & gdo in (3:8)					 			THEN esc=3;

/* Casos no especificados CINE 2011, NIVEL 9 */
						  *[Nor. o tc/comer., ante. no espec.];
IF niv in (5,6) & ant=9 			     			THEN esc=9;
											  *[Niv. no espec.];
IF niv=99 							   				THEN esc=9;

                     /* Fin de escolaridad */


/* Variable de recodificacin de horas trabajadas mensuales
        NOTA. Un mes promedio del ao tiene 4.345238 semanas
        1a posib. Hrs. trabajadas la semana pasada son las habituales
        2a posib. No trabaj la semana psada
        3a posib. Hrs. que trabaj la semana pasada no son las hab.
 		Horas trabajadas mensuales 2015 (COE_15 ampliado) */

hrmes=.;
/*Qu das y cuntas horas le dedic...a su trabajo la semana pasada? Total de horas*/
&c._thrs_n=&c._thrs+0;
/*Qu das y cuntas horas le dedica habituralmente... a su trabajo? Total de horas*/
&d._thrs_n=&d._thrs+0;
/*La semana pasada, ...tuvo poco trabajo qu hacer? 1=s; 2=no trabaj la semana pasada*/
&e._n=&e+0;
/*Ese es el nmero de horas que habitualmente trabaja...? 1=s; 2=No;*/
&f._n=&f+0;
  *1a posibilidad;
IF (0<&c._thrs_n<999) AND &f._n=1 THEN hrmes=&c._thrs_n*4.345238;
  *2a posibilidad;
IF (0<&d._thrs_n<999) AND &e._n=2 THEN hrmes=&d._thrs_n*4.345238;
  *3a posibilidad;
IF (0<&d._thrs_n<999) AND &f._n=2 THEN hrmes=&d._thrs_n*4.345238;
  * No especificados;
IF &c._thrs_n=999 OR &d._thrs_n=999 THEN hrmes=.;
RUN;
%mend;
%create(o=C, b=15, j=p3j1, c=p5b, d=p5d, e=p5,  f=p5c);

/* Revisin de poblaciones */
/* Nota: Si se tabulan las siguentes frecuencias, es necesario cerrar la ventana del Output antes de correr la siguiente maro.
 
PROC FREQ DATA=ENOE215a; TABLES r_def /ALL; WHERE r_def='00' and c_res in ('1','3'); WEIGHT fac; RUN; 
PROC FREQ DATA=ENOE215a; tables sexo*edad/nopercent norow nocol; WHERE r_def='00' and c_res in ('1','3'); WEIGHT fac; RUN; 
PROC FREQ DATA=ENOE215a; table po/nopercent norow nocol; where edad>14; weight fac; run; 

/* 	Poblacin total 	  120,846,274;                              
		Hombres:		   58,577,668;                              
		Mujeres:		   62,268,606; 
La poblacin ocupada de 15 y ms de la base coincide con los tabulados de Inegi: 50,336,088; */


/*    PROCESO PREVIO PARA CALCULAR EL SALARIO MENSUAL PROMEDIO	 */
/* Clculo del salario promedio de quienes reciben salarios >=10 SalMin,subordinados remunerados, segn grupo de edad.  */

%MACRO create2(i=, s=);
/* Guarda en la carpeta indicada los archivos */
ODS HTML FILE="&s10.\S10SM&i._&s..xls"
STYLE=barrettsblue;
DATA Enoe215sh&i._&s;
SET Enoe215a;
salmens=p6b2+0;
IF (&i<=edad<=&s) & pos=1;
RUN;
Proc freq data=Enoe215sh&i._&s; 
table edad; 
weight fac; 
run; 
DATA SH_10&i._&s;
SET Enoe215sh&i._&s;
IF salmens>=salario*10;
RUN;

PROC UNIVARIATE DATA=SH_10&i._&s FREQ NORMAL;
VAR salmens;
RUN;
ODS HTML CLOSE;
%mend;
* Jvenes;
%create2(i=15, s=29);
%create2(i=15, s=19);	
%create2(i=20, s=24);
%create2(i=25, s=29);
* Adultos;
%create2(i=25, s=64);
%create2(i=25, s=44);
%create2(i=45, s=64);

/*Se verifica que no haya outliers muy extremos y se obtiene la Media de cada grupo de edad 
 *FRECUENCIAS; 
	pob1529 =           11635608; 
	pob1519 =           2181511;
	pob2024 =           4536142;
	pob2529 =           4917955;
	pob2564 =           26701145;
	pob2544 =           18177272;
	pob4564 =           8523873;
* PROC UNIVARIATE; 
	pob1529: Media =     29918.05;
 	pob1519: Media =     28287.14; 
 	pob2024: Media =     30504.16;
 	pob2529: Media =     29833.18;
 	pob2564: Media =     30619.7;
 	pob2544: Media =     29917.41;
 	pob4564: Media =     31496.72;
*/


/* CLCULO DEL SALARIO HORARIO RELATIVO, POR ENTIDAD FEDERATIVA Y CARACTERSTICAS NACIONALES */

%MACRO create3(b=, i=, s=, salr=, shr1=, shr2=);
DATA ENOE2&b.a&i._&s;
SET ENOE2&b.a;
/* Actualmente el salario mnimo mensual es de...cantidad que obtiene al mes? */
p6c_n=p6c+0;
/* Recibe o le pagan: 9=no le pagan ni recibe ingresos */
p6_9n=p6_9+0;
/* Aparte de lo que me acaba de mencionar obtiene o le pagan sus ingresos: 
   opcin 3=no le pagan ni recibe ingresos */
p6a3_n=p6a3+0;
/* Cul es el nombre de la empresa...para la que trabaja: opcin 4= Es un trab. extranjero */
p4_n=p4+0;
salmens=.;
/* Cada cundo obtiene...sus ingresos o le paga? Cantidad cuando la pregunta 6b=1,2,3,4,5, 6 */
salmens=p6b2+0;
/* Pob. segn grupo de edad ocupada subordinados remunerados; */
IF (&i<=edad<=&s) & po=1 & pos=1;
 IF p6c_n=1 THEN salmens=salario*0.5;   /* menor */
 IF p6c_n=2 THEN salmens=salario;       /* igual a esta cantidad */
 IF p6c_n=3 THEN salmens=salario*1.5;   /* 1<salario mnimo<=2 */
 IF p6c_n=4 THEN salmens=salario*2.5;   /* 2<salario mnimo<=3 */
 IF p6c_n=5 THEN salmens=salario*4.0;   /* 3<salario mnimo<=5 */
 IF p6c_n=6 THEN salmens=salario*7.5;   /* 5<salario mnimo<=10 */
 IF p6c_n=7 THEN salmens=&salr;         /* Salario promedio de los que declararon 
                                           que reciben ms de 10 SM.; */
 IF p6_9n=9 OR p6a3_n=3 THEN salmens=0; /* No reciben ingresos; */
 IF p6c_n IN (8,9)OR p4_n=4 OR p6b2=999999 THEN salmens=.; /* NE */
salhr=salmens/hrmes; /* Salario nominal por hora; */
Run;

/* Tablas */
DATA ENOE2&b.c&i._&s;
SET ENOE2&b.a&i._&s
(KEEP=key salmens salhr pos esc po edad estado sexo locur est upm fac);
IF (&shr1<=salhr=<&shr2);
RUN;

/* Guarda en la carpeta indicada los archivos */
ODS HTML FILE="&shr.\SHR&b.c&i._&s..xls"
STYLE=barrettsblue;
* Salario por entidad federativa para la tabla RE02c-1;
PROC SORT DATA=ENOE2&b.c&i._&s; BY esc; RUN;
PROC SURVEYMEANS DATA=ENOE2&b.c&i._&s NOBS SUMWGT MEAN CLM;
VAR salhr;
STRATA est;
CLUSTER upm;
WEIGHT fac;
DOMAIN estado;
BY esc;
RUN;

/* Caractersticas del salario nacional tabla RE02c-2 y anexo */
PROC SORT DATA=ENOE2&b.c&i._&s; BY sexo esc locur; RUN; 
PROC SURVEYMEANS DATA=ENOE2&b.c&i._&s NOBS SUMWGT MEAN CLM;
VAR salhr;
STRATA est;
CLUSTER upm;
WEIGHT fac;
DOMAIN sexo*esc locur*esc esc sexo locur;
RUN;

/* Frecuencia nacional de la poblacin trabajadora remunerada */
PROC FREQ DATA=ENOE2&b.c&i._&s;
TABLES 
po pos esc*locur esc*sexo edad/missing nocol norow nopercent;
WEIGHT fac;
RUN;
ODS HTML CLOSE;

%mend;
* Jvenes;
%create3(b=15, i=15, s=29, salr=29918.05, shr1=0.01, shr2=99999999);
%create3(b=15, i=15, s=19, salr=28287.14, shr1=0.01, shr2=99999999);
%create3(b=15, i=20, s=24, salr=30504.16, shr1=0.01, shr2=99999999);
%create3(b=15, i=25, s=29, salr=29833.18, shr1=0.01, shr2=99999999);
* Adultos;
%create3(b=15, i=25, s=64, salr=30619.7, shr1=0.01, shr2=99999999);
%create3(b=15, i=25, s=44, salr=29917.41, shr1=0.01, shr2=99999999);
%create3(b=15, i=45, s=64, salr=31496.72, shr1=0.01, shr2=99999999);



/* SIGNIFICANCIA ESTADSTICA: ADAPTACIN DE LA MACRO DE DEGANTE */

DATA entidad; 		INPUT Dominio $1-9 Ent $12-14 Entidad $16-35; DATALINES;
_Nacional	33	Nacional
estado=1	01	Aguascalientes
estado=2	02	Baja California
estado=3	03	Baja California Sur
estado=4	04	Campeche
estado=5	05	Coahuila
estado=6	06	Colima
estado=7	07	Chiapas
estado=8	08	Chihuahua
estado=9	09	Distrito Federal
estado=10	10	Durango
estado=11	11	Guanajuato
estado=12	12	Guerrero
estado=13	13	Hidalgo
estado=14	14	Jalisco
estado=15	15	Mexico
estado=16	16	Michoacan
estado=17	17	Morelos
estado=18	18	Nayarit
estado=19	19	Nuevo Leon
estado=20	20	Oaxaca
estado=21	21	Puebla
estado=22	22	Queretaro
estado=23	23	Quintana Roo
estado=24	24	San Luis Potosi
estado=25	25	Sinaloa
estado=26	26	Sonora
estado=27	27	Tabasco
estado=28	28	Tamaulipas
estado=29	29	Tlaxcala
estado=30	30	Veracruz
estado=31	31	Yucatan
estado=32	32	Zacatecas
; RUN;
PROC FORMAT; VALUE ESTIMADOR 1='Significativo' 0='No significativo'; RUN;

OPTIONS SYMBOLGEN;
%MACRO ESTIMADORES(year=, ini=, fin=);
ods output estimates=estimaciones_&ini._&fin ; 
PROC surveyreg data=Enoe2&year.c&ini._&fin; WHERE ESC IN (0:3);
	  CLASS estado esc;
      STRATA est;
      MODEL  salhr = esc /solution NOINT ;
      WEIGHT fac;
	  DOMAIN estado;

/* Estimacin de los promedios del salario horario por entidad y nivel de escolaridad */
ESTIMATE 'Sin basica' 		ESC 1 0 0 0;
ESTIMATE 'Basica' 			ESC 0 1 0 0;
ESTIMATE 'Media Superior'	ESC 0 0 1 0;
ESTIMATE 'Superior' 		ESC 0 0 0 1;

/* Estimacin de las diferencia en los promedios del salario horario por entidad y nivel de escolaridad */
ESTIMATE 'Sin basica vs Media Superior' ESC 1 0 -1 0;
ESTIMATE 'Basica vs Media Superior' 	ESC 0 1 -1 0;
ESTIMATE 'Superior vs Media Superior' 	ESC 0 0 -1 1;
ESTIMATE 'Sin basica vs Basica' 		ESC 1 -1 0 0;
ESTIMATE 'Media Superior vs Basica' 	ESC 0 -1 1 0;
ESTIMATE 'Superior vs Basica' 			ESC 0 -1 0 1;
RUN ;
DATA estimaciones_&ini._&fin._2; SET estimaciones_&ini._&fin;
IF Probt<0.05 THEN significativo=1; ELSE significativo=0; 
IF ESTIMATE=. THEN SIGNIFICATIVO=.;
IF dominio = '' THEN dominio='_Nacional';
DROP LABEL DF StdErr Probt tValue;
RUN;
PROC SORT DATA=estimaciones_&ini._&fin._2; BY DOMINIO; RUN;
PROC TRANSPOSE DATA = estimaciones_&ini._&fin._2
	OUT=TABLA_&ini._&fin._1;
	BY DOMINIO;
	ID StmtNo;
	VAR ESTIMATE;
RUN;
PROC TRANSPOSE DATA = estimaciones_&ini._&fin._2
	OUT=TABLA_&ini._&fin._2;
	BY DOMINIO;
	ID StmtNo;
	VAR SIGNIFICATIVO;
RUN;
DATA TABLA_&ini._&fin._2; SET TABLA_&ini._&fin._2;
RENAME 
_1=SIGNI_1
_2=SIGNI_2
_3=SIGNI_3
_4=SIGNI_4
_5=SIGNI_5
_6=SIGNI_6
_7=SIGNI_7
_8=SIGNI_8
_9=SIGNI_9
_10=SIGNI_10; 
DROP _NAME_;
RUN;
PROC SORT DATA=TABLA_&ini._&fin._1; BY DOMINIO; RUN;
PROC SORT DATA=TABLA_&ini._&fin._2; BY DOMINIO; RUN;
DATA TABLA_&ini._&fin._FINAL; MERGE TABLA_&ini._&fin._1 TABLA_&ini._&fin._2; BY DOMINIO; RUN;
DATA TABLA_&ini._&fin._FINAL; SET TABLA_&ini._&fin._FINAL;
LABEL
_1='Sin basica'
_2='Basica'
_3='Media Superior'
_4='Superior'
_5='Sin basica vs Media Superior'
_6='Basica vs Media Superior'
_7='Superior vs Media Superior'
_8='Sin basica vs Basica'
_9='Media Superior vs Basica'
_10='Superior vs Basica'
SIGNI_1='SIGNI Sin basica'
SIGNI_2='SIGNI Basica'
SIGNI_3='SIGNI Media Superior'
SIGNI_4='SIGNI Superior'
SIGNI_5='SIGNI Sin basica vs Media Superior'
SIGNI_6='SIGNI Basica vs Media Superior'
SIGNI_7='SIGNI Superior vs Media Superior'
SIGNI_8='SIGNI Sin basica vs Basica'
SIGNI_9='SIGNI Media Superior vs Basica'
SIGNI_10='SIGNI Superior vs Basica';
FORMAT SIGNI_1 ESTIMADOR.
SIGNI_2 ESTIMADOR.
SIGNI_3 ESTIMADOR.
SIGNI_4 ESTIMADOR.
SIGNI_5 ESTIMADOR.
SIGNI_6 ESTIMADOR.
SIGNI_7 ESTIMADOR.
SIGNI_8 ESTIMADOR.
SIGNI_9 ESTIMADOR.
SIGNI_10 ESTIMADOR.;
DROP _NAME_ _LABEL_;
RUN ;
PROC SORT DATA=TABLA_&ini._&fin._FINAL; BY DOMINIO; RUN;
PROC SORT DATA=ENTIDAD; BY DOMINIO; RUN;
DATA TABLA_&ini._&fin._FINAL; MERGE ENTIDAD TABLA_&ini._&fin._FINAL; BY DOMINIO; DROP DOMINIO; 
RUN;
DATA TABLA_&ini._&fin._FINAL; RETAIN ENT ENTIDAD _1 SIGNI_1 _2 SIGNI_2 _3 SIGNI_3 _4 SIGNI_4 _5 SIGNI_5 _6 SIGNI_6
_7 SIGNI_7 _8 SIGNI_8 _9 SIGNI_9 _10 SIGNI_10; SET TABLA_&ini._&fin._FINAL; 
SHR_SINBAS_BAS=_1/_2; SHR_MS_BAS=_3/_2; SHR_SUP_BAS=_4/_2; SHR_SINBAS_MS=_1/_3; SHR_BAS_MS=_2/_3; SHR_SUP_MS=_4/_3;
LABEL
SHR_SINBAS_BAS='Sal rel sin bs VS bs'
SHR_MS_BAS='Sal rel ms VS bs'
SHR_SUP_BAS='Sal rel sup VS bs'
SHR_SINBAS_MS='Sal rel sin bs VS ms'
SHR_BAS_MS='Sal rel bs VS ms'
SHR_SUP_MS='Sal rel sup VS ms';
RUN;
PROC SORT DATA=TABLA_&ini._&fin._FINAL; BY ENT; RUN;
%MEND;
* Jvenes;
%ESTIMADORES(year=15, ini=15, fin=29);
%ESTIMADORES(year=15, ini=15, fin=19);	
%ESTIMADORES(year=15, ini=20, fin=24);
%ESTIMADORES(year=15, ini=25, fin=29);
* Adultos;
%ESTIMADORES(year=15, ini=25, fin=64);
%ESTIMADORES(year=15, ini=25, fin=44);
%ESTIMADORES(year=15, ini=45, fin=64);


/* ADAPTACIN PARA SUBPOBLACIONES (SEXO Y TAMAO DE LOCALIDAD) */
/* Comparacin entre niveles de escolaridad dentro de una subpoblacin */

DATA tabla_sexo; INPUT Dominio $1-6 Sexo $7-17; 
DATALINES;
sexo=1 01 Hombres
sexo=2 02 Mujeres
; 
RUN;

DATA tabla_locur; INPUT Dominio $1-7 locur $8-21;
DATALINES;
locur=1 01 Urbano
locur=2 02 Semiurbano
locur=3 03 Rural
;
RUN;

OPTIONS SYMBOLGEN;
%MACRO ESTIMADORES2(year=, ini=, fin=, dom=);
ods output estimates=estimaciones_&dom._&ini._&fin; 
PROC surveyreg data=Enoe2&year.c&ini._&fin; WHERE ESC IN (0:3);
	  CLASS &dom esc;
      STRATA est;
      MODEL  salhr = esc /solution NOINT ;
      WEIGHT fac;
	  DOMAIN &dom;

/* Estimacin de los promedios del salario horario por sexo y nivel de escolaridad */
ESTIMATE 'Sin basica' 		ESC 1 0 0 0;
ESTIMATE 'Basica' 			ESC 0 1 0 0;
ESTIMATE 'Media Superior'	ESC 0 0 1 0;
ESTIMATE 'Superior' 		ESC 0 0 0 1;

/* Estimacin de las diferencias en los promedios del salario horario por sexo y nivel de escolaridad */
ESTIMATE 'Sin basica vs Media Superior' ESC 1 0 -1 0;
ESTIMATE 'Basica vs Media Superior' 	ESC 0 1 -1 0;
ESTIMATE 'Superior vs Media Superior' 	ESC 0 0 -1 1;
ESTIMATE 'Sin basica vs Basica' 		ESC 1 -1 0 0;
ESTIMATE 'Media Superior vs Basica' 	ESC 0 -1 1 0;
ESTIMATE 'Superior vs Basica' 			ESC 0 -1 0 1;
RUN ;
DATA estimaciones_&dom._&ini._&fin; SET estimaciones_&dom._&ini._&fin; where dominio ne '';
	IF Probt<0.05 THEN significativo=1; ELSE significativo=0; 
	IF ESTIMATE=. THEN SIGNIFICATIVO=.;
	DROP LABEL DF StdErr Probt tValue;
RUN;
PROC SORT DATA=estimaciones_&dom._&ini._&fin; BY DOMINIO; RUN;
PROC TRANSPOSE DATA = estimaciones_&dom._&ini._&fin
	OUT=TABLA_&ini._&fin._1_&dom;
	BY DOMINIO;
	ID StmtNo;
	VAR ESTIMATE;
RUN;
PROC TRANSPOSE DATA = estimaciones_&dom._&ini._&fin
	OUT=TABLA_&ini._&fin._2_&dom;
	BY DOMINIO;
	ID StmtNo;
	VAR SIGNIFICATIVO;
RUN;
DATA TABLA_&ini._&fin._2_&dom; SET TABLA_&ini._&fin._2_&dom;
	RENAME 
	_1=SIGNI_1
	_2=SIGNI_2
	_3=SIGNI_3
	_4=SIGNI_4
	_5=SIGNI_5
	_6=SIGNI_6
	_7=SIGNI_7
	_8=SIGNI_8
	_9=SIGNI_9
	_10=SIGNI_10; 
	DROP _NAME_;
RUN;
PROC SORT DATA=TABLA_&ini._&fin._1_&dom; BY DOMINIO; RUN;
PROC SORT DATA=TABLA_&ini._&fin._2_&dom; BY DOMINIO; RUN;
DATA TABLA_&ini._&fin._FINAL_&dom; MERGE TABLA_&ini._&fin._1_&dom TABLA_&ini._&fin._2_&dom; BY DOMINIO; RUN;
DATA TABLA_&ini._&fin._FINAL_&dom; SET TABLA_&ini._&fin._FINAL_&dom;
	LABEL
	_1='Sin basica'
	_2='Basica'
	_3='Media Superior'
	_4='Superior'
	_5='Sin basica vs Media Superior'
	_6='Basica vs Media Superior'
	_7='Superior vs Media Superior'
	_8='Sin basica vs Basica'
	_9='Media Superior vs Basica'
	_10='Superior vs Basica'
	SIGNI_1='SIGNI Sin basica'
	SIGNI_2='SIGNI Basica'
	SIGNI_3='SIGNI Media Superior'
	SIGNI_4='SIGNI Superior'
	SIGNI_5='SIGNI Sin basica vs Media Superior'
	SIGNI_6='SIGNI Basica vs Media Superior'
	SIGNI_7='SIGNI Superior vs Media Superior'
	SIGNI_8='SIGNI Sin basica vs Basica'
	SIGNI_9='SIGNI Media Superior vs Basica'
	SIGNI_10='SIGNI Superior vs Basica';
	FORMAT SIGNI_1 ESTIMADOR.
	SIGNI_2 ESTIMADOR.
	SIGNI_3 ESTIMADOR.
	SIGNI_4 ESTIMADOR.
	SIGNI_5 ESTIMADOR.
	SIGNI_6 ESTIMADOR.
	SIGNI_7 ESTIMADOR.
	SIGNI_8 ESTIMADOR.
	SIGNI_9 ESTIMADOR.
	SIGNI_10 ESTIMADOR.;
	DROP _NAME_ _LABEL_;
RUN ;
PROC SORT DATA=TABLA_&ini._&fin._FINAL_&dom; BY DOMINIO; RUN;
DATA TABLA_&ini._&fin._FINAL_&dom; MERGE tabla_&dom TABLA_&ini._&fin._FINAL_&dom; BY DOMINIO; RUN;
DATA TABLA_&ini._&fin._FINAL_&dom; RETAIN &dom _1 SIGNI_1 _2 SIGNI_2 _3 SIGNI_3 _4 SIGNI_4 _5 SIGNI_5 _6 SIGNI_6
_7 SIGNI_7 _8 SIGNI_8 _9 SIGNI_9 _10 SIGNI_10; SET TABLA_&ini._&fin._FINAL_&dom; 
SHR_SINBAS_BAS=_1/_2; SHR_MS_BAS=_3/_2; SHR_SUP_BAS=_4/_2; SHR_SINBAS_MS=_1/_3; SHR_BAS_MS=_2/_3; SHR_SUP_MS=_4/_3;
LABEL
	SHR_SINBAS_BAS='Sal rel sin bs VS bs'
	SHR_MS_BAS='Sal rel ms VS bs'
	SHR_SUP_BAS='Sal rel sup VS bs'
	SHR_SINBAS_MS='Sal rel sin bs VS ms'
	SHR_BAS_MS='Sal rel bs VS ms'
	SHR_SUP_MS='Sal rel sup VS ms';
	DROP DOMINIO;
RUN;
%MEND;
/* Sexo */
* Jvenes;
%ESTIMADORES2(year=15, ini=15, fin=29, dom=sexo);
%ESTIMADORES2(year=15, ini=15, fin=19, dom=sexo);	
%ESTIMADORES2(year=15, ini=20, fin=24, dom=sexo);
%ESTIMADORES2(year=15, ini=25, fin=29, dom=sexo);
* Adultos;
%ESTIMADORES2(year=15, ini=25, fin=64, dom=sexo);
%ESTIMADORES2(year=15, ini=25, fin=44, dom=sexo);
%ESTIMADORES2(year=15, ini=45, fin=64, dom=sexo);
/* Tamao de localidad */
* Jvenes;
%ESTIMADORES2(year=15, ini=15, fin=29, dom=locur);
%ESTIMADORES2(year=15, ini=15, fin=19, dom=locur);	
%ESTIMADORES2(year=15, ini=20, fin=24, dom=locur);
%ESTIMADORES2(year=15, ini=25, fin=29, dom=locur);
* Adultos;
%ESTIMADORES2(year=15, ini=25, fin=64, dom=locur);
%ESTIMADORES2(year=15, ini=25, fin=44, dom=locur);
%ESTIMADORES2(year=15, ini=45, fin=64, dom=locur);

/*	SIGNIFICANCIA ENTRE SEXO POR NIVELES DE ESCOLARIDAD */ 

PROC FORMAT; VALUE ESTIMADOR 1='Significativo' 0='No significativo'; 
RUN;

OPTIONS SYMBOLGEN;
%MACRO ESTIMADORES4(year=, ini=, fin=);
ods output estimates=estimaciones4_&ini._&fin. ;
PROC surveyreg data=Enoe215a&ini._&fin. ; WHERE sexo IN (0:2) AND ESC IN (0:3);
      CLASS ESC SEXO;
      STRATA est;
      MODEL  salhr = SEXO /solution NOINT ;
      WEIGHT fac;
      DOMAIN esc;
/* Estimacin de los promedios de salario por sexo y nivel de escolaridad */
ESTIMATE 'HOMBRES'         sexo 1 0;
ESTIMATE 'MUJERES'         sexo 0 1;

/* Estimacin de las diferencias en los promedios de salario por sexo y nivel de escolaridad */
ESTIMATE 'HOMBRES vs MUJERES' sexo 1 -1;
ESTIMATE 'MUJERES vs HOMBRES' sexo -1 1;
RUN ;
DATA estimaciones4_&ini._&fin._2; SET estimaciones4_&ini._&fin;
    IF Probt<0.05 THEN significativo=1; ELSE significativo=0;
    IF ESTIMATE=. THEN SIGNIFICATIVO=.;
    IF dominio = '' THEN dominio='_total';
    DROP LABEL DF StdErr Probt tValue;
RUN;
PROC SORT DATA=estimaciones4_&ini._&fin._2; BY DOMINIO; RUN;
PROC TRANSPOSE DATA = estimaciones4_&ini._&fin._2
    OUT=TOSEXO2_&ini._&fin._1;
    BY DOMINIO;
    ID StmtNo;
    VAR ESTIMATE;
RUN;
PROC TRANSPOSE DATA = estimaciones4_&ini._&fin._2
    OUT=TOSEXO2_&ini._&fin._2;
    BY DOMINIO;
    ID StmtNo;
    VAR SIGNIFICATIVO;
RUN;
DATA TOSEXO2_&ini._&fin._2; SET TOSEXO2_&ini._&fin._2;
    RENAME
   _1=SIGNI_1
    _2=SIGNI_2
    _3=SIGNI_3
    _4=SIGNI_4;
    DROP _NAME_;
    RUN;
PROC SORT DATA=TOSEXO2_&ini._&fin._1; BY DOMINIO; RUN;
PROC SORT DATA=TOSEXO2_&ini._&fin._2; BY DOMINIO; RUN;
DATA TOSEXO2_&ini._&fin._FINAL; MERGE TOSEXO2_&ini._&fin._1 TOSEXO2_&ini._&fin._2; BY DOMINIO; RUN;
DATA TOSEXO2_&ini._&fin._FINAL; SET TOSEXO2_&ini._&fin._FINAL;
    LABEL
    _1='HOMBRES'
    _2='MUJERES'
    _3='HOMBRES VS MUJERES'
    _4='MUJERES VS HOMBRES'
    SIGNI_1='SIGNI HOMBRES'
    SIGNI_2='SIGNI MUJERES'
    SIGNI_3='SIGNI HOMBRES VS MUJERES'
    SIGNI_4='SIGNI MUJERES VS HOMBRES';
    FORMAT 
	SIGNI_1 ESTIMADOR.
    SIGNI_2 ESTIMADOR.
    SIGNI_3 ESTIMADOR.
    SIGNI_4 ESTIMADOR.;
    DROP _NAME_ _LABEL_;
    RUN ;
		PROC SORT DATA=TOSEXO2_&ini._&fin._FINAL; BY DOMINIO; RUN;
DATA TOSEXO2_&ini._&fin._FINAL; RETAIN NIV NIVEL _1 SIGNI_1 _2 SIGNI_2 _3 SIGNI_3 _4 SIGNI_4 ; SET TOSEXO2_&ini._&fin._FINAL;
SAL_SINBAS_BAS=_1/_2; SAL_MS_BAS=_2/_1;
LABEL
    SAL_SINBAS_BAS='SALARIO HOMBRES VS MUJERES'
    SAL_MS_BAS='SALARIO MUJERES VS HOMBRES';
RUN;
PROC SORT DATA=TOSEXO2_&ini._&fin._FINAL; BY dominio; RUN;
%MEND;
* Jvenes;
%ESTIMADORES4(year=15, ini=15, fin=29);
%ESTIMADORES4(year=15, ini=15, fin=19);	
%ESTIMADORES4(year=15, ini=20, fin=24);
%ESTIMADORES4(year=15, ini=25, fin=29);
* Adultos;
%ESTIMADORES4(year=15, ini=25, fin=64);
%ESTIMADORES4(year=15, ini=25, fin=44);
%ESTIMADORES4(year=15, ini=45, fin=64);


/* SIGNIFICANCIA ENTRE TAMAO DE LOCALIDAD POR NIVELES DE ESCOLARIDAD */

PROC FORMAT; VALUE ESTIMADOR 1='Significativo' 0='No significativo'; 
RUN;

OPTIONS SYMBOLGEN;
%MACRO ESTIMADORES5(year=, ini=, fin=);
ods output estimates=estimaciones5_&ini._&fin ;
PROC surveyreg data=Enoe2&year.a&ini._&fin; WHERE ESC IN (0:3) AND LOCUR IN (0:3);
		CLASS ESC LOCUR;
      	STRATA est;
      	MODEL  salhr = LOCUR /solution NOINT ;
      	WEIGHT fac;
      	DOMAIN esc;

/* Estimacin de los promedios de salario por tamao de localidad y nivel de escolaridad */
ESTIMATE 'RURAL'         LOCUR 1 0 0;
ESTIMATE 'SEMIURBAN'     LOCUR 0 1 0;
ESTIMATE 'URBAN'         LOCUR 0 0 1;

/* Estimacin de las diferencias en los promedios de salario por tamao de localidad y nivel de escolaridad */
ESTIMATE 'RURAL vs SEMIURBAN' LOCUR 1 -1 0;
ESTIMATE 'SEMIURBAN vs URBAN' LOCUR 0 1 -1;
ESTIMATE 'RURAL vs URBAN' LOCUR 1 0 -1;
ESTIMATE 'SEMIURBAN vs RURAL' LOCUR -1 1 0;
ESTIMATE 'URBAN vs SEMIURBAN' LOCUR 0 -1 1;
ESTIMATE 'URBAN vs RURAL' LOCUR -1 0 1;
RUN ;
DATA estimaciones5_&ini._&fin._2; SET estimaciones5_&ini._&fin;
IF Probt<0.05 THEN significativo=1; ELSE significativo=0;
    IF ESTIMATE=. THEN SIGNIFICATIVO=.;
    IF dominio = '' THEN dominio='_total';
    DROP LABEL DF StdErr Probt tValue;
RUN;
PROC SORT DATA=estimaciones5_&ini._&fin._2; BY DOMINIO; RUN;
PROC TRANSPOSE DATA = estimaciones5_&ini._&fin._2
OUT=TLOC2_&ini._&fin._1;
    BY DOMINIO;
    ID StmtNo;
    VAR ESTIMATE;
RUN;
PROC TRANSPOSE DATA = estimaciones5_&ini._&fin._2
OUT=TLOC2_&ini._&fin._2;
    BY DOMINIO;
    ID StmtNo;
    VAR SIGNIFICATIVO;
RUN;
DATA TLOC2_&ini._&fin._2; SET TLOC2_&ini._&fin._2;
    RENAME
   _1=SIGNI_1
    _2=SIGNI_2
    _3=SIGNI_3
    _4=SIGNI_4
	_5=SIGNI_5
	_6=SIGNI_6
	_7=SIGNI_7
	_8=SIGNI_8
	_9=SIGNI_9;
    DROP _NAME_;
    RUN;
PROC SORT DATA=TLOC2_&ini._&fin._1; BY DOMINIO; RUN;
PROC SORT DATA=TLOC2_&ini._&fin._2; BY DOMINIO; RUN;
DATA TLOC2_&ini._&fin._FINAL; MERGE TLOC2_&ini._&fin._1 TLOC2_&ini._&fin._2; BY DOMINIO; RUN;
DATA TLOC2_&ini._&fin._FINAL; SET TLOC2_&ini._&fin._FINAL;
    LABEL
    _1='RURAL'
    _2='SEMIURBAN'
    _3='URBAN'
	_4='RURAL VS SEMIURBAN'
    _5='SEMIURBAN VS URBAN'
	_6='RURAL VS URBAN'
	_7='SEMIURBAN VS RURAL'
	_8='URBAN VS SEMIURBAN'
	_9='URBAN VS RURAL'
    SIGNI_1='SIGNI RURAL'
    SIGNI_2='SIGNI SEMIURBAN'
	SIGNI_3='SIGNI URBAN'
    SIGNI_4='SIGNI RURAL VS SEMIURBAN'
    SIGNI_5='SIGNI SEMIURBAN VS URBAN'
	SIGNI_6='SIGNI RURAL VS URBAN'
    SIGNI_7='SIGNI SEMIURBAN VS RURAL'
    SIGNI_8='SIGNI URBAN VS SEMIURBAN'
	SIGNI_9='SIGNI URBAN VS RURAL';
    FORMAT 
	SIGNI_1 ESTIMADOR.
    SIGNI_2 ESTIMADOR.
    SIGNI_3 ESTIMADOR.
    SIGNI_4 ESTIMADOR.
	SIGNI_5 ESTIMADOR.
	SIGNI_6 ESTIMADOR.
	SIGNI_7 ESTIMADOR.
	SIGNI_8 ESTIMADOR.
	SIGNI_9 ESTIMADOR.;
    DROP _NAME_ _LABEL_;
    RUN ;
PROC SORT DATA=TLOC2_&ini._&fin._FINAL; BY DOMINIO; RUN;

DATA TLOC2_&ini._&fin._FINAL; RETAIN NIV NIVEL _1 SIGNI_1 _2 SIGNI_2 _3 SIGNI_3 _4 SIGNI_4 _5 SIGNI_5 _6 SIGNI_6
_7 SIGNI_7 _8 SIGNI_8 _9 SIGNI_9; SET TLOC2_&ini._&fin._FINAL; run;

%MEND;
* Jvenes;
%ESTIMADORES5(year=15, ini=15, fin=29);
%ESTIMADORES5(year=15, ini=15, fin=19);	
%ESTIMADORES5(year=15, ini=20, fin=24);
%ESTIMADORES5(year=15, ini=25, fin=29);
* Adultos;
%ESTIMADORES5(year=15, ini=25, fin=64);
%ESTIMADORES5(year=15, ini=25, fin=44);
%ESTIMADORES5(year=15, ini=45, fin=64);

/* Limpia de Work las tablas no necesarias */

PROC DATASETS LIBRARY=WORK NOLIST;
	DELETE  COE1T215 COE2T215 ENOE215 ENOE215A ENOE215A15_19 ENOE215A15_29 ENOE215A20_24 ENOE215A25_29 ENOE215A25_44 ENOE215A25_64 
            ENOE215A45_64 ENOE215C15_19 ENOE215C15_29 ENOE215C20_24 ENOE215C25_29 ENOE215C25_44 ENOE215C25_64 ENOE215C45_64 ENOE215SH15_19 
            ENOE215SH15_29 ENOE215SH20_24 ENOE215SH25_29 ENOE215SH25_44 ENOE215SH25_64 ENOE215SH45_64 ENTIDAD ESTIMACIONES4_15_19 ESTIMACIONES4_15_19_2 
            ESTIMACIONES4_15_29 ESTIMACIONES4_15_29_2 ESTIMACIONES4_20_24 ESTIMACIONES4_20_24_2 ESTIMACIONES4_25_29 ESTIMACIONES4_25_29_2 
			ESTIMACIONES4_25_44 ESTIMACIONES4_25_44_2 ESTIMACIONES4_25_64 ESTIMACIONES4_25_64_2 ESTIMACIONES4_45_64 ESTIMACIONES4_45_64_2 ESTIMACIONES5_15_19 
            ESTIMACIONES5_15_19_2 ESTIMACIONES5_15_29 ESTIMACIONES5_15_29_2 ESTIMACIONES5_20_24 ESTIMACIONES5_20_24_2 ESTIMACIONES5_25_29 ESTIMACIONES5_25_29_2 
            ESTIMACIONES5_25_44 ESTIMACIONES5_25_44_2 ESTIMACIONES5_25_64 ESTIMACIONES5_25_64_2 ESTIMACIONES5_45_64 ESTIMACIONES5_45_64_2 ESTIMACIONES_15_19 
            ESTIMACIONES_15_19_2 ESTIMACIONES_15_29 ESTIMACIONES_15_29_2 ESTIMACIONES_20_24 ESTIMACIONES_20_24_2 ESTIMACIONES_25_29 ESTIMACIONES_25_29_2 
            ESTIMACIONES_25_44 ESTIMACIONES_25_44_2 ESTIMACIONES_25_64 ESTIMACIONES_25_64_2 ESTIMACIONES_45_64 ESTIMACIONES_45_64_2 ESTIMACIONES_LOCUR_15_19 
            ESTIMACIONES_LOCUR_15_29 ESTIMACIONES_LOCUR_20_24 ESTIMACIONES_LOCUR_25_29 ESTIMACIONES_LOCUR_25_44 ESTIMACIONES_LOCUR_25_64 ESTIMACIONES_LOCUR_45_64 
            ESTIMACIONES_SEXO_15_19 ESTIMACIONES_SEXO_15_29 ESTIMACIONES_SEXO_20_24 ESTIMACIONES_SEXO_25_29 ESTIMACIONES_SEXO_25_44 ESTIMACIONES_SEXO_25_64 
            ESTIMACIONES_SEXO_45_64 SDEMT215 SH_1015_19 SH_1015_29 SH_1020_24 SH_1025_29 SH_1025_44 SH_1025_64 SH_1045_64 TABLA_15_19_1 TABLA_15_19_1_LOCUR 
            TABLA_15_19_1_SEXO TABLA_15_19_2 TABLA_15_19_2_LOCUR TABLA_15_19_2_SEXO TABLA_15_29_1 TABLA_15_29_1_LOCUR TABLA_15_29_1_SEXO TABLA_15_29_2 TABLA_15_29_2_LOCUR 
            TABLA_15_29_2_SEXO TABLA_20_24_1 TABLA_20_24_1_LOCUR TABLA_20_24_1_SEXO TABLA_20_24_2 TABLA_20_24_2_LOCUR TABLA_20_24_2_SEXO TABLA_25_29_1 TABLA_25_29_1_LOCUR 
            TABLA_25_29_1_SEXO TABLA_25_29_2 TABLA_25_29_2_LOCUR TABLA_25_29_2_SEXO TABLA_25_44_1 TABLA_25_44_1_LOCUR TABLA_25_44_1_SEXO TABLA_25_44_2 TABLA_25_44_2_LOCUR 
            TABLA_25_44_2_SEXO TABLA_25_64_1 TABLA_25_64_1_LOCUR TABLA_25_64_1_SEXO TABLA_25_64_2 TABLA_25_64_2_LOCUR TABLA_25_64_2_SEXO TABLA_45_64_1 TABLA_45_64_1_LOCUR 
            TABLA_45_64_1_SEXO TABLA_45_64_2 TABLA_45_64_2_LOCUR TABLA_45_64_2_SEXO TABLA_LOCUR TABLA_SEXO TLOC2_15_19_1 TLOC2_15_19_2 TLOC2_15_29_1 TLOC2_15_29_2 
            TLOC2_20_24_1 TLOC2_20_24_2 TLOC2_25_29_1 TLOC2_25_29_2 TLOC2_25_44_1 TLOC2_25_44_2 TLOC2_25_64_1 TLOC2_25_64_2 TLOC2_45_64_1 TLOC2_45_64_2 TOSEXO2_15_19_1 
            TOSEXO2_15_19_2 TOSEXO2_15_29_1 TOSEXO2_15_29_2 TOSEXO2_20_24_1 TOSEXO2_20_24_2 TOSEXO2_25_29_1 TOSEXO2_25_29_2 TOSEXO2_25_44_1 TOSEXO2_25_44_2 TOSEXO2_25_64_1 
            TOSEXO2_25_64_2 TOSEXO2_45_64_1 TOSEXO2_45_64_2 _DOCTMP000000000000000000000 _DOCTMP000000000000000000001 _DOCTMP000000000000000000002 _DOCTMP000000000000000000003 
            _DOCTMP000000000000000000004 _DOCTMP000000000000000000005 _DOCTMP000000000000000000006 _DOCTMP000000000000000000007 _DOCTMP000000000000000000008 _DOCTMP000000000000000000009 
            _DOCTMP000000000000000000010 _DOCTMP000000000000000000011 _DOCTMP000000000000000000012 _DOCTMP000000000000000000013 _DOCTMP000000000000000000014 _DOCTMP000000000000000000015 
            _DOCTMP000000000000000000016 _DOCTMP000000000000000000017 _DOCTMP000000000000000000018 _DOCTMP000000000000000000019 _DOCTMP000000000000000000020 _DOCTMP000000000000000000021 
            _DOCTMP000000000000000000022 _DOCTMP000000000000000000023 _DOCTMP000000000000000000024 _DOCTMP000000000000000000025 _DOCTMP000000000000000000026 _DOCTMP000000000000000000027 
            _DOCTMP000000000000000000028 _DOCTMP000000000000000000029 _DOCTMP000000000000000000030 _DOCTMP000000000000000000031 _DOCTMP000000000000000000032 _DOCTMP000000000000000000033 
            _DOCTMP000000000000000000034 _DOCTMP000000000000000000035 _DOCTMP000000000000000000036 _DOCTMP000000000000000000037 _DOCTMP000000000000000000038 _DOCTMP000000000000000000039 
            _DOCTMP000000000000000000040 _DOCTMP000000000000000000041 _DOCTMP000000000000000000042 _DOCTMP000000000000000000043 _DOCTMP000000000000000000044 _DOCTMP000000000000000000045 
            _DOCTMP000000000000000000046 _DOCTMP000000000000000000047 _DOCTMP000000000000000000048 _DOCTMP000000000000000000049 _DOCTMP000000000000000000050 _DOCTMP000000000000000000051 
            _DOCTMP000000000000000000052 _DOCTMP000000000000000000053 _DOCTMP000000000000000000054 _DOCTMP000000000000000000055 _DOCTMP000000000000000000056 _DOCTMP000000000000000000057 
            _DOCTMP000000000000000000058;
RUN;



/* FIN DEL PROGRAMA */


